// ****************** Copyright Header ************************************
// WebWisdom JavaScript Shared Browser Version 3.0
// Copyright 1999 Syracuse University and WebWisdom.com
// Author: Geoffrey C. Fox
// Contact: support@webwisdom.com
//
// Reproduction of this software without this Copyright Header
// is prohibited and it constitutes a violation of
// the SU and WebWisdom.com Copyright (a federal felony).
//
// This software cannot be incorporated into any commercial
// product, or a product supporting commercial activity,
// without first obtaining a license from WebWisdom.com
// E-mail license@webwisdom.com to apply.
// *********** End of Copyright Header ************************************
//
// Set of Routines to handle JavaScript Events
// Serialized Event has format Header followed by Data
// Header and Data are separated by String WW_Separator2
// Header Items in header are separated by WW_Separator1
// Header is format,targetflag,type,sourcetime,sourceflag, with , replaced by WW_Separator1
// Data (including initial separator from header) has format
// WW_Separator2 num , value where , is separator and num is an integer defined as WW_defineeventproperty.num
// value is stored as event.tag where tag is WW_defineeventproperty.tag
// if WW_defineeventproperty.escape is true one uses escape/unescape to encode/decode value
// A special tag is arraysize which must be followed in same data stream by arraysize
// children terminated by an endchild tag

function WW_generatedevent(username,streamflag,grouplabel,sequencenumber,type)	{ // Define basic event with minimal properties

	this.format = WW_EventFormat;
	this.type = type;
	var today = new Date();
	this.sourcename = username;
	this.sourcetime = today.getTime();
	this.sourceflag = streamflag;
	this.tangogrouplabel = grouplabel;
	this.tangosequencenumber = sequencenumber;
	this.reject = false;
	this.infotype = 2; // Updating

}	// End WW_generatedevent(type)

function WW_childevent(type)	{ // Define very basic child event

	this.type = type;

}	// End WW_childevent(type)

function WW_basicevent()	{ // Define very basic parent event

	this.format = WW_EventFormat;

}	// End WW_basicevent()

function WW_gottenevent()	{ // Define received event with minimal properties

	this.format = WW_EventFormat;
	var today = new Date();
	this.targettime = today.getTime();
	this.reject = false;
	this.processed = 0;

}	// End WW_gottenevent()

function WW_returnevent()	{ // Define return event with minimal properties

	this.format = WW_EventFormat;
	var today = new Date();
	this.sourcetime = today.getTime();
	this.reject = false;

}	// End WW_returnevent()

function WW_defineeventtype(value,reason)	{

	this.value = value;
	this.reason = reason;
	WW_typelist[value] = this;

}	// End WW_definetype(value,reason)

function WW_defineeventproperty(tag,num,reason,proptype) {	// Define Event Properties
//	proptype 0 ASCII 1 Integer 2 Float 3 Boolean 5 Object 6 Null

	this.tag = tag;
	this.num = num.toString();
	this.reason = reason;
	this.escape = false;
	this.header = false;
	this.compare = true;
	this.proptype = proptype;
	WW_eventlist[num] = this;
	WW_eventasslist[tag] = this;

} // End WW_defineevent(tag,num,reason)

function WW_compareevents(ev1,ev2)	{ // Return True if ev1 and ev2 identical

	if(WW_isundefined(ev1))
		return false;
	if(WW_isundefined(ev2))
		return false;
	for( var m in ev1)	{
		if(WW_isundefined(WW_eventasslist[m]))
			continue;
		if( !WW_eventasslist[m].compare)
			continue;
		if(WW_isundefined(ev1[m]))
			continue;
		if(WW_isundefined(ev2[m]))
			return false;
		var proptype = WW_eventasslist[m].proptype;
		if( proptype == 5 )
			continue;
		var val = ev1[m];
		if( ev1[m] != ev2[m] )
			return false;
	}
	for( var m in ev2)	{
		if(WW_isundefined(WW_eventasslist[m]))
			continue;
		if( !WW_eventasslist[m].compare)
			continue;
		if(WW_isundefined(ev2[m]))
			continue;
		if(WW_isundefined(ev1[m]))
			return false;
	}
	var evchildct1 = ev1.arraysize;
	var evchildarray1 = ev1.arrayitself;
	var evchildct2 = ev2.arraysize;
	var evchildarray2 = ev2.arrayitself;
	if(WW_isundefined(evchildct1) || WW_isundefined(evchildarray1))	{
		if( WW_isundefined(evchildct2) || WW_isundefined(evchildarray2) )
			return true;
		return false;
	}
	if(WW_isundefined(evchildct2) || WW_isundefined(evchildarray2)) 
		return false;
	if( evchildct1 != evchildct2 )
		return false;
	for( var m=0; m < evchildct1; m++)	{
		if( !WW_compareevents(evchildarray1[m],evchildarray2[m]) )
			return false;
	}
	return true;

}	// End WW_compareevents(ev1,ev2)

function WW_cloneevent(wwevent)	{ // Return wwevent copied in wweventclone

	var wweventclone = {};
	if(WW_isundefined(wwevent))
		return wweventclone;
	for( var m in wwevent)	{
		if(WW_isundefined(WW_eventasslist[m]))
                        continue;
                if(WW_isundefined(wwevent[m]))
                        continue;
                var proptype = WW_eventasslist[m].proptype;
                if( proptype == 5 )
			continue;
		wweventclone[m] = wwevent[m];
	}
	var evchildct = wwevent.arraysize;
	var evchildarray = wwevent.arrayitself;
	if(WW_isundefined(evchildct) || WW_isundefined(evchildarray))	{
		return wweventclone;
	}
	wweventclone.arraysize = evchildct;
	wweventclone.arrayitself = new Array();
	for( var m=0; m < evchildct; m++)	{
		wweventclone.arrayitself[m] = WW_cloneevent(evchildarray[m]);
	}
	return wweventclone;

}	// End WW_cloneevent(wwevent)

function WW_packevent(wwevent,target,message)	{ // Serialize wwevent

	if(WW_isundefined(wwevent))
		return '';
	if( target != '' )
		wwevent.targetflag = target;
	if(WW_isundefined(wwevent.targetflag))
		wwevent.targetflag = WW_Eventanyname;
	var mess = WW_EventFormat + WW_EventSeparator1 + wwevent.targetflag + WW_EventSeparator1 + wwevent.type + WW_EventSeparator1 + wwevent.sourcetime + WW_EventSeparator1 + wwevent.sourceflag + WW_EventSeparator1;
	if( message != '' )
		wwevent.message = message;
	for( var m in wwevent)	{
		if(WW_isundefined(WW_eventasslist[m]))
			continue;
		if( WW_eventasslist[m].header)
			continue;
		if(WW_isundefined(wwevent[m]))
			continue;
		var val = wwevent[m];
		var proptype = WW_eventasslist[m].proptype;
		if( proptype == 5 )	{
			var arraysize = wwevent.arraysize;
			if(WW_isundefined(arraysize))
				continue;
			if( arraysize <= 0 )
				continue;
			mess += WW_eventasslist[m].num + WW_EventSeparator1 + arraysize.toString() + WW_EventSeparator2;
			for(var arrayct =0; arrayct < arraysize; arrayct++)	{
				mess += WW_packarray(val[arrayct]); }
			continue; }
		if( proptype == 6 )
			val = '';
		else	{
		if( proptype > 0 )
			val = val.toString();
		}
		if( WW_eventasslist[m].escape)
			val =escape(val);
		mess = mess + WW_eventasslist[m].num + WW_EventSeparator1 + val + WW_EventSeparator2;
	} // End loop over properties of wwevent
	return mess;

}	// End WW_packevent(target,message)

function WW_packarray(wwchildevent)	{ // Serialize Childevent

	var mess = '';
	for( var m in wwchildevent)	{
		if(WW_isundefined(WW_eventasslist[m]))
			continue;
		var val = wwchildevent[m];
		var proptype = WW_eventasslist[m].proptype;
		if( proptype == 5 )	{
			var arraysize = wwchildevent.arraysize;
			if(WW_isundefined(arraysize))
				continue;
			if( arraysize <= 0 )
				continue;
			mess += WW_eventasslist[m].num + WW_EventSeparator1 + arraysize.toString() + WW_EventSeparator2;
			for(var arrayct =0; arrayct < arraysize; arrayct++)	{
				mess += WW_packarray(val[arrayct]); }
			continue; }
		if( proptype == 6 )
			val = '';
		else	{
		if( proptype > 0 )
			val = val.toString();
		}
		if( WW_eventasslist[m].escape)
			val =escape(val);
		mess = mess + WW_eventasslist[m].num + WW_EventSeparator1 + val + WW_EventSeparator2;
	} // End loop over properties of wwchildevent
	return (mess + WW_eventasslist["endchild"].num + WW_EventSeparator1 + WW_EventSeparator2);

}	// End WW_packarray(wwchildevent)

function WW_getevent(charstring,wwevent)	{ // Define Event from datastream
// set wwevent.reject = true if a rejected event from header processing
// set wwevent.error if error in processing

// First Analyse header
	var beginchar =0;
	var stopper = -WW_Eventsepsize1;
	for( var m=0; m < 5; m++ )	{
		beginchar = stopper+WW_Eventsepsize1;
		stopper = charstring.indexOf(WW_EventSeparator1,beginchar);
		if(stopper < 0 )	{
			wwevent.error = 1;
			wwevent.data = charstring;
			return; }
		var localtest =  charstring.substring(beginchar,stopper);
		if( m==0 )	{ // Format
			if( localtest != WW_EventFormat)	{
				wwevent.error = 2;
				wwevent.data = charstring;
				return; }
			wwevent.format = localtest;
			continue; }
		if( m == 1 )	{ // Target flag
			wwevent.targetflag = localtest;
			if( !WW_testoneventtarget)
				continue;
			if( localtest == WW_Eventtimename )
				continue;
			if( localtest == WW_Eventanyname )	{
				continue; }
			if( localtest == WW_Eventmastername )	{
				if(WW_tangostatus != 0 )	{ // reject
					wwevent.reject = true;
					return; }
				continue;
			}
			if( localtest == WW_Eventnonmastername )	{
				if(WW_tangostatus == 0 )	{ // reject
					wwevent.reject = true;
					return; }
				continue;
			}
			if( localtest != WW_localflag )	{
				wwevent.reject = true;
				return; }
			continue;
		}	// End Target flag Processing
		if( m == 2 )
			wwevent.type = localtest;
		if( m == 3 )
			wwevent.sourcetime = parseInt(localtest);
		if( m == 4 )
			wwevent.sourceflag = localtest;
	}	// End loop over header entries
	beginchar = stopper+WW_Eventsepsize1;
	var len = charstring.length
	while(beginchar < len)	{
		stopper = charstring.indexOf(WW_EventSeparator1,beginchar);
		var localpropnum = charstring.substring(beginchar,stopper);
		localpropnum = parseInt(localpropnum);
		if(WW_isundefined(WW_eventlist[localpropnum]))	{
			wwevent.error = 3;
			wwevent.data = charstring;
			return; }
		beginchar = stopper+WW_Eventsepsize1;
		stopper = charstring.indexOf(WW_EventSeparator2,beginchar);
		var localval =  charstring.substring(beginchar,stopper);
		beginchar = stopper+WW_Eventsepsize2;
		if(WW_eventlist[localpropnum].escape)
			localval =  unescape(localval);
		var localtype = WW_eventlist[localpropnum].proptype;
		var localprop = WW_eventlist[localpropnum].tag;
		if( localtype == 5 )	{
			wwevent.arrayitself = new Array();
			beginchar = WW_getchildevent(charstring,beginchar,wwevent,wwevent.arrayitself,parseInt(localval))
			if(WW_isdefined(wwevent.error))
				return;
			continue; }
		if( localtype == 6 )	{
			wwevent.error = 4;
			wwevent.data = charstring;
			return; }
		if( localtype == 1)
			localval =  parseInt(localval);
		if( localtype == 2 )
			localval =  parseFloat(localval);
		if( localtype == 3 )	{
			if( localval == "true" )
				wwevent[localprop] = true;
			else	{
				wwevent[localprop] = false; }
			continue;
		}
		wwevent[localprop] = localval;
	} // End loop over trailer
	return;

}	// End WW_getevent(datastream,wwevent)

function WW_getchildevent(charstring,oldbeginchar,wwevent,wwchildevent,arraysize)	{

	var len = charstring.length
	var beginchar = oldbeginchar;
	var countthruarray =0;
	wwchildevent[countthruarray] = {};
	while(beginchar < len)	{
		stopper = charstring.indexOf(WW_EventSeparator1,beginchar);
		var localpropnum = charstring.substring(beginchar,stopper);
		localpropnum = parseInt(localpropnum);
		if(WW_isundefined(WW_eventlist[localpropnum]))	{
			wwevent.error = 5;
			wwevent.data = charstring;
			return; }
		beginchar = stopper+WW_Eventsepsize1;
		stopper = charstring.indexOf(WW_EventSeparator2,beginchar);
		var localval =  charstring.substring(beginchar,stopper);
		beginchar = stopper+WW_Eventsepsize2;
		if(WW_eventlist[localpropnum].escape)
			localval =  unescape(localval);
		var localtype = WW_eventlist[localpropnum].proptype;
		var localprop = WW_eventlist[localpropnum].tag;
		if( localtype == 5 )	{
			wwchildevent[countthruarray].arrayitself = new Array();
			beginchar = WW_getchildevent(charstring,beginchar,wwevent,wwchildevent[countthruarray].arrayitself,parseInt(localval))
			if(WW_isdefined(wwevent.error))
				return;
			continue; }
		if( localtype == 6 )	{
			++countthruarray;
			if( countthruarray >= arraysize )
				return beginchar;
			wwchildevent[countthruarray] = {};
			continue; }
		if( localtype == 1)
			localval =  parseInt(localval);
		if( localtype == 2 )
			localval =  parseFloat(localval);
		if( localtype == 3 )	{
			if( localval == "true" )
				wwchildevent[countthruarray][localprop] = true;
			else	{
				wwchildevent[countthruarray][localprop] = false; }
			continue;
		}
		wwchildevent[countthruarray][localprop] = localval;
	} // End loop over trailer
	return beginchar;

}	// End WW_getchildevent(charstring,beginchar,wwchildevent)

function WW_printeventmodel()	{

	var locwindow = window.open("","EventModel");
	locwindow.document.open("text/html");
	locwindow.document.writeln("<h2>WebWisdom JavaScript Event Properties</h2>");
	for(var m in WW_eventasslist)	{
		locwindow.document.writeln("<b>" + WW_eventasslist[m].num + ": " + WW_eventasslist[m].tag + " -- </b>" + WW_eventasslist[m].reason + "<br>");
	}
	locwindow.document.writeln("<h2>WebWisdom JavaScript Event Types</h2>");
	for(var m in WW_typelist)	{
		locwindow.document.writeln("<b>" + WW_typelist[m].value + " -- </b>" + WW_typelist[m].reason + "<br>");
	}
	locwindow.document.close();

}	// End WW_printeventmodel()

function WW_printevent(wwevent)	{

	var locwindow = window.open("","SingleEvent");
	locwindow.document.open("text/html");
	locwindow.document.writeln("<h2>WebWisdom Properties of a Single Event</h2>");
	var childtodo = false;
	for(var m in wwevent)	{
		if( WW_eventasslist[m].num == "18" )	{
			childtodo = true;
			continue; }
		locwindow.document.writeln("<b>" + WW_eventasslist[m].num + ": " + WW_eventasslist[m].tag + " -- </b>" + WW_eventasslist[m].reason + ' -- <b>' + wwevent[m].toString() + "</b><br>");
	}
	if( childtodo)	{
		locwindow.document.writeln("<b>Start set of Children</b><br>");
		WW_printchildevent(wwevent.arrayitself,wwevent.arraysize,locwindow); }
	locwindow.document.close();

}	// End WW_printevent()

function WW_printchildevent(wwchildevent,arrayct,locwindow)	{

	if(arrayct<=0)
		return;
	for(var runthruarray=0; runthruarray<arrayct; runthruarray++)	{
		var childtodo = false;
		for(var m in wwchildevent[runthruarray])	{
			if( WW_eventasslist[m].num == "18" )	{
				childtodo = true;
				continue; }
			locwindow.document.writeln("<b>Child:" + runthruarray.toString() + ' ' + WW_eventasslist[m].num + ": " + WW_eventasslist[m].tag + " -- </b>" + WW_eventasslist[m].reason + ' -- <b>' + wwchildevent[runthruarray][m].toString() + "</b><br>");
		}
		if( childtodo)	{
			locwindow.document.writeln("<b>Start set of Children</b><br>");
			WW_printchildevent(wwchildevent[runthruarray].arrayitself,wwchildevent[runthruarray].arraysize,locwindow); }
	}

}	// End WW_printchildevent()

function WW_javaprintevent(wwevent)	{

	var childtodo = false;
	for(var m in wwevent)	{
		if( WW_eventasslist[m].num == "18" )	{
			childtodo = true;
			continue; }
		java.lang.System.out.println(WW_eventasslist[m].num + ": " + WW_eventasslist[m].tag + " --" + WW_eventasslist[m].reason + ' -- ' + wwevent[m].toString());
	}
	if( childtodo)	{
		java.lang.System.out.println("Start set of Children");
		WW_javaprintchildevent(wwevent.arrayitself,wwevent.arraysize); }

}	// End WW_printevent()

function WW_javaprintchildevent(wwchildevent,arrayct)	{

	if(arrayct<=0)
		return;
	for(var runthruarray=0; runthruarray<arrayct; runthruarray++)	{
		var childtodo = false;
		for(var m in wwchildevent[runthruarray])	{
			if( WW_eventasslist[m].num == "18" )	{
				childtodo = true;
				continue; }
			java.lang.System.out.println("Child:" + runthruarray.toString() + ' ' + WW_eventasslist[m].num + ": " + WW_eventasslist[m].tag + " -- " + WW_eventasslist[m].reason + ' -- ' + wwchildevent[runthruarray][m].toString());
		}
		if( childtodo)	{
			java.lang.System.out.println("Start set of Children");
			WW_javaprintchildevent(wwchildevent[runthruarray].arrayitself,wwchildevent[runthruarray].arraysize); }
	}

}	// End WW_javaprintchildevent()

var WW_EventSeparator1 = ',';
var WW_EventSeparator2 = '@@WW@@';
var WW_Eventsepsize1 = 1;
var WW_Eventsepsize2 = 6;
var WW_Eventlocalname = 'local';
var WW_Eventmastername = 'master';
var WW_Eventnonmastername = 'nonmaster';
var WW_Eventtimename = 'netmaster';
var WW_Eventanyname = 'any';
var WW_testoneventtarget = true;
var WW_EventFormat = 'WWdec98';

WW_eventlist = new Array();
WW_eventasslist = new Array();
WW_typelist = new Array();

// Define Event Properties ***********************************************
WW_rejecteventprop = new WW_defineeventproperty("reject",0,"Local reject flag",3);
WW_rejecteventprop.header = true;
WW_rejecteventprop.compare = false;
WW_originalsourcetimeeventprop = new WW_defineeventproperty("originalsourcetime",1,"Original Absolute Time of Event at Source",1);
WW_originalsourcetimeeventprop.compare = false;
WW_originaltargettimeeventprop = new WW_defineeventproperty("originaltargettime",2,"Original Absolute Time of Event at Target",1);
WW_originaltargettimeeventprop.compare = false;
WW_formateventprop = new WW_defineeventproperty("format",3,"Label of Current Format Used by Events",0);
WW_formateventprop.compare = false;
WW_formateventprop.header = true;
WW_typeeventprop = new WW_defineeventproperty("type",4,"Type of Event",0);
WW_typeeventprop.compare = false;
WW_typeeventprop.header = true;
WW_sourcetimeeventprop = new WW_defineeventproperty("sourcetime",5,"Absolute Time of Event at Source",1);
WW_sourcetimeeventprop.compare = false;
WW_sourcetimeeventprop.header = true;
WW_targettimeeventprop = new WW_defineeventproperty("targettime",6,"Absolute Time of Event at Target",1);
WW_targettimeeventprop.compare = false;
WW_dispatchsourcetimeeventprop = new WW_defineeventproperty("dispatchsourcetime",7,"Absolute Time of Event at Dispatch Source",1);
WW_dispatchsourcenameeventprop = new WW_defineeventproperty("dispatchsourcename",8,"Name of Dispatch Source",0);
WW_sourcenameeventprop = new WW_defineeventproperty("sourcename",9,"User Name of Source",0);
WW_sourcenameeventprop.escape = true;
WW_sourceflageventprop = new WW_defineeventproperty("sourceflag",10,"Unique Flag of Source",0);
WW_sourceflageventprop.header = true;
WW_targetnameeventprop = new WW_defineeventproperty("targetname",11,"User Name of Target",0);
WW_targetnameeventprop.escape = true;
WW_targetflageventprop = new WW_defineeventproperty("targetflag",12,"Unique Flag of Target",0);
WW_targetflageventprop.header = true;
WW_separatoreventprop = new WW_defineeventproperty("separator",13,"Separator used in trailer",0);
WW_sessionlabeleventprop = new WW_defineeventproperty("sessionlabel",14,"Label of Session",0);
WW_sessionlabeleventprop.escape = true;
WW_messageeventprop = new WW_defineeventproperty("message",15,"Message Associated with Event",0);
WW_messageeventprop.compare = false;
WW_messageeventprop.escape = true;
WW_dataeventprop = new WW_defineeventproperty("data",16,"Unprocessed data associated with event",0);
WW_dataeventprop.compare = false;
WW_arraysizeeventprop = new WW_defineeventproperty("arraysize",17,"Array Size",1);
WW_arrayitselfeventprop = new WW_defineeventproperty("arrayitself",18,"Array Itself",5);
WW_endchildeventprop = new WW_defineeventproperty("endchild",19,"End Current Child",6);
WW_timeskeweventprop = new WW_defineeventproperty("timeskew",20,"Time Skew",2);
WW_measuredtimeeventprop = new WW_defineeventproperty("measuredtime",21,"Measured Time",1);
WW_playernumbereventprop = new WW_defineeventproperty("playernumber",22,"Player Number",1);
WW_parameternumbereventprop = new WW_defineeventproperty("parameternumber",23,"Parameter Number",1);
WW_stringparametervalueeventprop = new WW_defineeventproperty("stringparametervalue",24,"String Parameter Value",0);
WW_stringparametervalueeventprop.escape = true;
WW_erroreventprop = new WW_defineeventproperty("error",25,"Error if Exists",1);
WW_innerheighteventprop = new WW_defineeventproperty("innerheight",26,"Inner Height of window",1);
WW_innerwidtheventprop = new WW_defineeventproperty("innerwidth",27,"Inner Width of window",1);
WW_processedeventprop = new WW_defineeventproperty("processed",28,"Flag to signify processed",1);
WW_processedeventprop.compare = false;
WW_majoreventprop = new WW_defineeventproperty("majorevent",29,"Flag to signify Associated Major Event",1);
WW_majoreventprop.compare = false;
WW_minoreventprop = new WW_defineeventproperty("minorevent",30,"Minor Event Number",1);
WW_minoreventprop.compare = false;
WW_infotypeeventprop = new WW_defineeventproperty("infotype",31,"Information Type 1(Location) 2(update) 3(DHTML) 4(Info) 5(Priority) 6(Internal Generated) 7(probe) 0(Heart)",1);
WW_infotypeeventprop.compare = false;
WW_tangosequencenumbereventprop = new WW_defineeventproperty("tangosequencenumber",32,"Sequence label of Originating Tango Event",1);
WW_tangosequencenumbereventprop.compare = false;
WW_tangogrouplabeleventprop = new WW_defineeventproperty("tangogrouplabel",33,"Time or other Label of Originating Tango Event",0);
WW_tangogrouplabeleventprop.compare = false;
WW_xscrolleventprop = new WW_defineeventproperty("xscroll",34,"x Scroll of window",1);
WW_yscrolleventprop = new WW_defineeventproperty("yscroll",35,"y Scroll of window",1);
WW_integerparametervalueeventprop = new WW_defineeventproperty("integerparametervalue",36,"Integer Parameter Value",1);
WW_floatparametervalueeventprop = new WW_defineeventproperty("floatparametervalue",37,"Floating Parameter Value",2);
WW_logicalparametervalueeventprop = new WW_defineeventproperty("logicalparametervalue",38,"Logical Parameter Value",3);
WW_usernameeventprop = new WW_defineeventproperty("username",39,"Username of Configuration",0);
WW_usernameeventprop.escape = true;
WW_preferredeventprop = new WW_defineeventproperty("preferred",40,"Preference Flag of Configuration",3);
WW_masteroptioneventprop = new WW_defineeventproperty("masteroption",41,"Master Option of Configuration",1);
WW_configtypeeventprop = new WW_defineeventproperty("configtype",42,"Type of Configuration",0);
WW_activeeventprop = new WW_defineeventproperty("active",43,"Active Flag for System Bookmark or Participant",3);
WW_numberstringeventprop = new WW_defineeventproperty("numberstring",44,"Iterating No for Thumbnail as string",0);
WW_precursoreventprop = new WW_defineeventproperty("precursor",45,"Precursor String for Thumbnail",0);
WW_precursoreventprop.escape = true;
WW_postcursoreventprop = new WW_defineeventproperty("postcursor",46,"Postcursor String for Thumbnail",0);
WW_postcursoreventprop.escape = true;
WW_lengthofnoeventprop = new WW_defineeventproperty("lengthofno",47,"Length of Number String for Thumbnail",1);
WW_currentnoeventprop = new WW_defineeventproperty("currentno",48,"Current No for Thumbnail",1);
WW_analyzedeventseventprop = new WW_defineeventproperty("analyzedevents",49,"Number of Timed events stored",1);
WW_eventtimingflageventprop = new WW_defineeventproperty("eventtimingflag",50,"Flag to designate Type of Timing Data",1);
WW_startmethodeventprop = new WW_defineeventproperty("startmethod",51,"Flag to designate How Start of Event Identified",1);
WW_endmethodeventprop = new WW_defineeventproperty("endmethod",52,"Flag to designate How End of Event Recognized",1);
WW_timeprobeflageventprop = new WW_defineeventproperty("timeprobeflag",53,"Time Probe Flag",1);
WW_downloadlabeleventprop = new WW_defineeventproperty("downloadlabel",54,"Download Image Site Flag",0);
WW_downloadlabeleventprop.escape = true;
WW_timestartedeventprop = new WW_defineeventproperty("timestarted",55,"Time Download Started",1);
WW_averageeventprop = new WW_defineeventproperty("average",56,"Average Download Time",2);
WW_stddeveventprop = new WW_defineeventproperty("stddev",57,"Standard Deviation",2);
WW_eventtodo0eventprop = new WW_defineeventproperty("eventtodo0",58,"Flag Heart Event Not done",1);
WW_eventtodo1eventprop = new WW_defineeventproperty("eventtodo1",59,"Count Location events Not done",1);
WW_eventtodo2eventprop = new WW_defineeventproperty("eventtodo2",60,"Count update Not done",1);
WW_eventtodo3eventprop = new WW_defineeventproperty("eventtodo3",61,"Count DHTML Events Not done",1);
WW_eventct1eventprop = new WW_defineeventproperty("eventct1",62,"Tramsmitted Event Count 1",1);
WW_eventct2eventprop = new WW_defineeventproperty("eventct2",63,"Tramsmitted Event Count 2",1);
WW_eventct3eventprop = new WW_defineeventproperty("eventct3",64,"Tramsmitted Event Count 3",1);
WW_updateflageventprop = new WW_defineeventproperty("updateflag",65,"Update Flag",1);
WW_adminmastereventprop = new WW_defineeventproperty("adminmaster",66,"Admin Master Status",3);
WW_netmastereventprop = new WW_defineeventproperty("netmaster",67,"Net Master Status",3);
WW_starttimeeventprop = new WW_defineeventproperty("starttime",68,"Participant Start Time(Master Clock)",1);
WW_endtimeeventprop = new WW_defineeventproperty("endtime",69,"Participant End Time(Master Clock)",1);
WW_windownumbereventprop = new WW_defineeventproperty("windownumber",70,"Window Number",1);


WW_layernameeventprop = new WW_defineeventproperty("layername",86,"Name of Layer",1);
WW_layernameeventprop.escape = true;
WW_linknumbereventprop = new WW_defineeventproperty("linknumber",87,"Index to Link in Page",1);
WW_linkcounteventprop = new WW_defineeventproperty("linkcount",88,"Number of Links in Page",1);
WW_linktypeeventprop = new WW_defineeventproperty("linktype",89,"Type of Link Event 0-5(click)6(over) 7(out)",1);
WW_linkhrefeventprop = new WW_defineeventproperty("linkhref",90,"href in Link",0);
WW_linkhrefeventprop.escape = true;
WW_linktexteventprop = new WW_defineeventproperty("linktext",91,"Text of Link",0);
WW_linktexteventprop.escape = true;
WW_layerleveleventprop = new WW_defineeventproperty("layerlevel",92,"Number of Layers Levels in frame",1);
WW_layercounteventprop = new WW_defineeventproperty("layercount",93,"Number of Layers in level",1);
WW_layernumbereventprop = new WW_defineeventproperty("layernumber",94,"Index to Layer in level",1);
WW_expectedurleventprop = new WW_defineeventproperty("expectedurl",95,"URL of Form or Link Submit",0);
WW_thumbnailurleventprop = new WW_defineeventproperty("thumbnailurl",96,"URL of Thumbnail",0);
WW_thumbnailurleventprop.escape = true;
WW_frameurleventprop = new WW_defineeventproperty("frameurl",97,"URL of Frame Page",0);
WW_frameurleventprop.escape = true;
WW_pagetitleeventprop = new WW_defineeventproperty("pagetitle",98,"Page Title",0);
WW_pagetitleeventprop.compare = false;
WW_pagetitleeventprop.escape = true;
WW_addonurleventprop = new WW_defineeventproperty("addonurl",99,"URL of Addon page",0);
WW_addonurleventprop.escape = true;
WW_currenturleventprop = new WW_defineeventproperty("currenturl",100,"URL of current page",0);
WW_currenturleventprop.escape = true;
WW_framecounteventprop = new WW_defineeventproperty("framecount",101,"Number of Frames in window",1);
WW_framenumbereventprop = new WW_defineeventproperty("framenumber",102,"Index to Frame in window",1);
WW_formnumbereventprop = new WW_defineeventproperty("formnumber",103,"Index to Form in Page",1);
WW_formlengtheventprop = new WW_defineeventproperty("formlength",104,"Number of Elements in Form",1);
WW_elementnumbereventprop = new WW_defineeventproperty("elementnumber",105,"Index to Element in Form",1);
WW_selectedindexeventprop = new WW_defineeventproperty("selectedindex",106,"Selected Index in Form Element",1);
WW_formtexteventprop = new WW_defineeventproperty("formtext",107,"Text or Textarea in Form Element",0);
WW_formtexteventprop.escape = true;
WW_formcounteventprop = new WW_defineeventproperty("formcount",108,"Number of Forms Recorded",1);
WW_formelementtypeeventprop = new WW_defineeventproperty("formelementtype",109,"Element type in Form",0);
WW_formelementcheckedeventprop = new WW_defineeventproperty("formelementchecked",110,"Checked value of Element in Form",3);
WW_reloadframenumbereventprop = new WW_defineeventproperty("reloadframenumber",111,"Reload this frame",1);
WW_dlurlstemeventprop = new WW_defineeventproperty("dlurlstem",121,"URLstem for Download Test",0);
WW_dlurlstemeventprop.escape = true;
WW_dlurlsuffixeventprop = new WW_defineeventproperty("dlurlsuffix",122,"URLsuffix for Download Test",0);
WW_dlurlcounteventprop = new WW_defineeventproperty("dlurlcount",123,"URLcount for Download Test",1);
WW_divxposeventprop = new WW_defineeventproperty("divxpos",131,"X Position of DHTML Entity",1);
WW_divyposeventprop = new WW_defineeventproperty("divypos",132,"Y Position of DHTML Entity",1);
WW_divzindexeventprop = new WW_defineeventproperty("divzindex",133,"z-index of DHTML Entity",1);
WW_divhideeventprop = new WW_defineeventproperty("divhide",134,"Hide(1)/Show(0) DHTML Entity",1);
WW_divscaleeventprop = new WW_defineeventproperty("divscale",135,"Scale of Current DHTML Image",2);
WW_divoptioneventprop = new WW_defineeventproperty("divoption",136,"Card Option",1);
WW_divfamilyeventprop = new WW_defineeventproperty("divfamily",137,"Family for Current DHTML Image",1);
WW_divmoodeventprop = new WW_defineeventproperty("divmood",138,"Mood/Orientation for Current DHTML Image",1);
WW_divbackeventprop = new WW_defineeventproperty("divback",139,"Back Choice for Current DHTML Image",1);
WW_divstatuseventprop = new WW_defineeventproperty("divstatus",140,"Status of Current DHTML Image",1);
WW_divindexeventprop = new WW_defineeventproperty("divindex",141,"Index of Current DHTML Image",1);
WW_divownereventprop = new WW_defineeventproperty("divowner",142,"Owner of Current DHTML Image",1);
WW_divrole1eventprop = new WW_defineeventproperty("divrole1",143,"Role1 of Current DHTML Image",1);
WW_divrole2eventprop = new WW_defineeventproperty("divrole2",144,"Role2 of Current DHTML Image",1);

// Define allowed types of events ********************************
WW_simplepagetype = new WW_defineeventtype("simplepage","Just a Page URL");
WW_hearttype = new WW_defineeventtype("heart","Just a Page URL in Heartbeat");
WW_linktype = new WW_defineeventtype("link","Defines a Captured Link");
WW_scrolltype = new WW_defineeventtype("scroll","Defines current scroll");
WW_formtype = new WW_defineeventtype("form","Contains One or More Forms");
WW_formtextchangetype = new WW_defineeventtype("formtextchange","Text Value for a Form element");
WW_formsinglelistchangetype = new WW_defineeventtype("formsinglelistchange","Single List Value in a Form element");
WW_formmultlistchangetype = new WW_defineeventtype("formmultlistchange","Multiple List Selected in a Form element");
WW_formclicktype = new WW_defineeventtype("formclick","Click on a Form element");
WW_formcheckedtype = new WW_defineeventtype("formchecked","Checked Status of a Form element");
WW_measuredtimetype = new WW_defineeventtype("measuredtime","Measured Time");
WW_synctype = new WW_defineeventtype("sync","Start Synchronization Phase");
WW_updatetype = new WW_defineeventtype("update","Participant Update");
WW_timeprobetype = new WW_defineeventtype("timeprobe","Timing Probe Initiate");
WW_cardtype = new WW_defineeventtype("card","Playing Card Update");
WW_pointerdefntype = new WW_defineeventtype("pointerdefn","Pointer Definition");
WW_setparametertype = new WW_defineeventtype("setparameter","Set Parameter");
WW_windowsizetype = new WW_defineeventtype("windowsize","Set Window Size");
WW_windowscrolltype = new WW_defineeventtype("windowscroll","Define Window Scroll");
WW_favoritestype = new WW_defineeventtype("favorites","Define Favorites");
WW_configtype = new WW_defineeventtype("config","Define Configuration");
WW_bookmarktype = new WW_defineeventtype("bookmark","Define System Bookmarks");
WW_thumbnailtype = new WW_defineeventtype("thumbnail","Thumbnail Object");
